# sample_project/main_asm

# Purchase Part

name | quantity | unit price | distributor | desctiption
sample_project/base_plate | 1 | 0.0 yen |  |
sample_project/bar_plate | 2 | 0.0 yen |  |
screw_m3/pan_10 | 8 | 3.5 yen | https://www.monotaro.com/p/3814/6604/ | sems screw is recommended
screw_m3/hollow_spacer_20 | 4 | 0.0 yen |  |

# Prepair Part

# Assembly Part

## sample_project/side_asm x2

### step 1

name | quantity
sample_project/bar_plate | 1

### step 2

name | quantity
screw_m3/pan_10 | 1
screw_m3/pan_10 | 1
screw_m3/hollow_spacer_20 | 1
screw_m3/hollow_spacer_20 | 1

## sample_project/main_asm x1

### step 1

name | quantity
sample_project/base_plate | 1

### step 2

name | quantity
sample_project/side_asm | 1
screw_m3/pan_10 | 1
screw_m3/pan_10 | 1

### step 3

name | quantity
sample_project/side_asm | 1
screw_m3/pan_10 | 1
screw_m3/pan_10 | 1

powered by roborecipe